/*********************************************************************
 * Licensed Materials - PropertyImpl of IBM                              *
 *                                                                   *
 * 5724-B88                                                          *
 *                                                                   *
 *  Copyright IBM Corp.  2001, 2002    All Rights Reserved.         *
 *                                                                   *
 * US Government Users Restricted Rights - Use, duplication or       *
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp. *
 *********************************************************************/

package com.ibm.websphere.query.base;

import java.util.ArrayList;
import java.util.List;

/**
	<P>The ArithmeticCondition class represents an arithmetic Operation in the query framework. 
	It can be used in a predicate.
	
	<P>This class contains an arithmetic operation and a vector of elements in which to perform that operation on.
 */
public class ArithmeticCondition implements IArithmeticCondition
{
  private List arithmeticConditionElements = new ArrayList();
  private String arithmeticOperation = "";

  /**
   * Constructor for ArithmeticCondition
   */
  public ArithmeticCondition()
  {
    super();
  }

  /**
   * @see IStringBuilder#buildString(ISelectQueryCallback2)
   */
  public String buildString(ISelectQueryCallback builder) throws QueryException
  {
    return builder.buildArithmeticCondition(this);
  }
  public void buildString(ISelectQueryCallback builder, StringBuffer sb) throws QueryException
  {
    builder.buildArithmeticCondition(this, sb);
  }

  /**
   * @see IArithmeticCondition#getArithmeticConditionElements()
   */
  public ILeftOperand[] getArithmeticConditionElements()
  {

    ILeftOperand[] ace = new ILeftOperand[arithmeticConditionElements.size()];

    for (int i = 0; i < arithmeticConditionElements.size(); i++)
    {
      ace[i] = (ILeftOperand) (arithmeticConditionElements.get(i));
    }

    return ace;
  }

  /**
   * @see IArithmeticCondition#getArithmeticOperation()
   */
  public String getArithmeticOperation()
  {
    return arithmeticOperation;
  }

  /**
  Tests for equality with the given object.
  */
  public boolean equals(Object o)
  {
    boolean eq = false;

    if (o instanceof ArithmeticCondition)
    {
      ArithmeticCondition ac = (ArithmeticCondition) o;

      if (arithmeticOperation != null)
      {
        eq = arithmeticOperation.equals(ac.arithmeticOperation);
      }
      else
      {
        eq = (ac.arithmeticOperation == null);
      }

      if (eq)
      {
        eq = arithmeticConditionElements.equals(ac.arithmeticConditionElements);
      }
    }
    return eq;
  }

  /**
   * Sets the arithmeticOperation
   * @param arithmeticOperation The arithmeticOperation to set
   */
  public void setArithmeticOperation(String arithmeticOperation)
  {
    this.arithmeticOperation = arithmeticOperation;
  }

  /**
   * Sets the arithmeticConditionElements
   * @param arithmeticConditionElements The arithmeticConditionElements to set
   */
  public void setArithmeticConditionElements(ILeftOperand[] newArithmeticConditionElements)
  {
    arithmeticConditionElements.clear();
    addArithmeticConditionElements(newArithmeticConditionElements);
  }

  public void addArithmeticConditionElement(ILeftOperand newArithmeticConditionElement)
  {
    arithmeticConditionElements.add(newArithmeticConditionElement);
  }

  public void addArithmeticConditionElements(ILeftOperand[] newArithmeticConditionElements)
  {
    for (int i = 0; i < newArithmeticConditionElements.length; i++)
    {
      arithmeticConditionElements.add(newArithmeticConditionElements[i]);
    }
  }

  /**
   * @see ILeftOperand#getDataType()
   */
  public int getDataType()
  {
    int dataType = Constants.DATATYPE_UNKNOWN;
    if (arithmeticConditionElements == null || arithmeticConditionElements.isEmpty())
    {
    }
    else
    {
      dataType = ((ILeftOperand) arithmeticConditionElements.get(0)).getDataType();
    }
    return dataType;
  }

}
