/*********************************************************************
 * Licensed Materials - PropertyImpl of IBM                          *
 *                                                                   *
 * 5724-B88                                                          *
 *                                                                   *
 *  Copyright IBM Corp.  2001, 2002    All Rights Reserved.         *
 *                                                                   *
 * US Government Users Restricted Rights - Use, duplication or       *
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp. *
 *********************************************************************/

package com.ibm.websphere.query.base;


/**
	<P>The Attribute class represents a general attribute in the query framework. It encapsulates 
	information about mapping to a domain specific attribute, for instance a table column in 
	database world, with a metadata object.
 */
public class Attribute implements IAttribute
{
  private String name;
  private ITable table;
  private int dataType = Constants.DATATYPE_UNKNOWN;    
  
  public Attribute(String name)
  {
    this.name = name;
  }
  
  public Attribute(String name, ITable table)
    {
      this.name = name;
      this.table = table;
    }
  
  public Attribute(String name, int dataType)
  {
    this.name = name;
    this.dataType = dataType;
  }
  
  public Attribute(String name, ITable table, int dataType)
    {
      this.name = name;
      this.table = table;
      this.dataType = dataType;
    }

  public String getName()
  {
    return name;
  }

  public void setName(String name)
  {
    this.name = name;
  }

  public ITable getTable()
  {    
    return table;
  }

  public void setTable(ITable table)
  {
    this.table = table;
  }

  public String buildString(ISelectQueryCallback builder) throws QueryException
  {
    return builder.buildAttribute(this);
  }
  public void buildString(ISelectQueryCallback builder, StringBuffer sb) throws QueryException
  {
    builder.buildAttribute(this, sb);
  }

  public boolean equals(Object o)
  {
    boolean eq = true;

    if (o instanceof Attribute)
    {
      Attribute a = (Attribute) o;

      if (name != null)
      {
        eq = name.equals(a.name);
      }
      else
      {
        eq = (a.name == null);
      }

      if (eq)
      {
        eq = (dataType == a.dataType);
      }
    }
    else
    {
      eq = false;
    }

    return eq;
  }
  
  public int getDataType()
  {
    return dataType;
  }

  public void setDataType(int dataType)
  {
    this.dataType = dataType;
  }
  
  public int hashCode()
  {
    int hashCode = 0;

    if (name != null)
      hashCode = name.hashCode();

    hashCode = hashCode + dataType;

    return hashCode;
  }

}
