/*********************************************************************
 * Licensed Materials - PropertyImpl of IBM                          *
 *                                                                   *
 * 5724-B88                                                          *
 *                                                                   *
 *  Copyright IBM Corp.  2001, 2002    All Rights Reserved.         *
 *                                                                   *
 * US Government Users Restricted Rights - Use, duplication or       *
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp. *
 *********************************************************************/

package com.ibm.websphere.query.base;

import java.io.Serializable;

/**
	<P>This class contains constants used in the query framework.
	
	<P>The main categories are data types, operations, and functions.
*/

public class Constants implements Serializable
{
  // Data types
  public static final int DATATYPE_UNKNOWN = -99;
  public static final int DATATYPE_LONGVARCHAR = -1;
  public static final int DATATYPE_BINARY = -2;
  public static final int DATATYPE_VARBINARY = -3;
  public static final int DATATYPE_LONGVARBINARY = -4;
  public static final int DATATYPE_BIGINT = -5;
  public static final int DATATYPE_TINYINT = -6;
  public static final int DATATYPE_BIT = -7;
  public static final int DATATYPE_NULL = 0;
  public static final int DATATYPE_CHAR = 1;
  public static final int DATATYPE_NUMERIC = 2;
  public static final int DATATYPE_DECIMAL = 3;
  public static final int DATATYPE_INTEGER = 4;
  public static final int DATATYPE_SMALLINT = 5;
  public static final int DATATYPE_FLOAT = 6;
  public static final int DATATYPE_REAL = 7;
  public static final int DATATYPE_DOUBLE = 8;
  public static final int DATATYPE_VARCHAR = 12;
  public static final int DATATYPE_DATE = 91;
  public static final int DATATYPE_TIME = 92;
  public static final int DATATYPE_TIMESTAMP = 93;
  public static final int DATATYPE_BLOB = 2004;
  public static final int DATATYPE_CLOB = 2005;
  public static final int DATATYPE_OTHER = 1111;

  public static final Integer DT_UNKNOWN = new Integer(DATATYPE_UNKNOWN);
  public static final Integer DT_LONGVARCHAR = new Integer(DATATYPE_LONGVARCHAR);
  public static final Integer DT_BINARY = new Integer(DATATYPE_BINARY);
  public static final Integer DT_VARBINARY = new Integer(DATATYPE_VARBINARY);
  public static final Integer DT_LONGVARBINARY = new Integer(DATATYPE_LONGVARBINARY);
  public static final Integer DT_BIGINT = new Integer(DATATYPE_BIGINT);
  public static final Integer DT_TINYINT = new Integer(DATATYPE_TINYINT);
  public static final Integer DT_BIT = new Integer(DATATYPE_BIT);
  public static final Integer DT_NULL = new Integer(DATATYPE_NULL);
  public static final Integer DT_CHAR = new Integer(DATATYPE_CHAR);
  public static final Integer DT_NUMERIC = new Integer(DATATYPE_NUMERIC);
  public static final Integer DT_DECIMAL = new Integer(DATATYPE_DECIMAL);
  public static final Integer DT_INTEGER = new Integer(DATATYPE_INTEGER);
  public static final Integer DT_SMALLINT = new Integer(DATATYPE_SMALLINT);
  public static final Integer DT_FLOAT = new Integer(DATATYPE_FLOAT);
  public static final Integer DT_REAL = new Integer(DATATYPE_REAL);
  public static final Integer DT_DOUBLE = new Integer(DATATYPE_DOUBLE);
  public static final Integer DT_VARCHAR = new Integer(DATATYPE_VARCHAR);
  public static final Integer DT_DATE = new Integer(DATATYPE_DATE);
  public static final Integer DT_TIME = new Integer(DATATYPE_TIME);
  public static final Integer DT_TIMESTAMP = new Integer(DATATYPE_TIMESTAMP);
  public static final Integer DT_BLOB = new Integer(DATATYPE_BLOB);
  public static final Integer DT_CLOB = new Integer(DATATYPE_CLOB);
  public static final Integer DT_OTHER = new Integer(DATATYPE_OTHER);

  // Single value operators
  public static final String OPERATOR_EQ = "=";
  public static final String OPERATOR_NEQ = "<>";
  public static final String OPERATOR_GT = ">";
  public static final String OPERATOR_GEQ = ">=";
  public static final String OPERATOR_LT = "<";
  public static final String OPERATOR_LEQ = "<=";
  public static final String OPERATOR_BTW = "BETWEEN";
  public static final String OPERATOR_IN = "IN";
  public static final String OPERATOR_LIKE = "LIKE";
  public static final String OPERATOR_NOT_LIKE = "NOTLIKE";
  public static final String OPERATOR_IS = "IS";
  public static final String OPERATOR_ISN = "ISNOT";

  // Multi value operators
  public static final String OPERATOR_MVALL = "MVALL";
  public static final String OPERATOR_MVANY = "MVANY";


  // Predicate operators
  public static final String OPERATOR_AND = "AND";
  public static final String OPERATOR_OR = "OR";

  // Order by operators
  public static final String OPERATOR_ASC = "ASC";
  public static final String OPERATOR_DES = "DES";

  public static final Operator OP_ASC = new Operator(OPERATOR_ASC);
  public static final Operator OP_DES = new Operator(OPERATOR_DES);
  public static final Operator OP_LIKE = new Operator(OPERATOR_LIKE);
  public static final Operator OP_NOT_LIKE = new Operator(OPERATOR_NOT_LIKE);
  public static final Operator OP_EQ = new Operator(OPERATOR_EQ);
  public static final Operator OP_NEQ = new Operator(OPERATOR_NEQ);
  public static final Operator OP_GT = new Operator(OPERATOR_GT);
  public static final Operator OP_LT = new Operator(OPERATOR_LT);
  public static final Operator OP_GEQ = new Operator(OPERATOR_GEQ);
  public static final Operator OP_LEQ = new Operator(OPERATOR_LEQ);
  public static final Operator OP_AND = new Operator(OPERATOR_AND);
  public static final Operator OP_OR = new Operator(OPERATOR_OR);
  public static final Operator OP_IS = new Operator(OPERATOR_IS);
  public static final Operator OP_ISNOT = new Operator(OPERATOR_ISN);
  public static final Operator OP_IN = new Operator(OPERATOR_IN);
  public static final Operator OP_BTW = new Operator(OPERATOR_BTW);

  // Functions
  public static final String FUNCTION_UPPER = "UPPER";
  public static final String FUNCTION_LOWER = "LOWER";
  public static final String FUNCTION_RIGHT = "RIGHT";
  public static final String FUNCTION_LEFT = "LEFT";
  public static final String FUNCTION_DATE = "DATE";
  public static final String FUNCTION_DAY = "DAY";
  public static final String FUNCTION_ABS = "ABS";
  public static final String FUNCTION_AVG = "AVG";
  public static final String FUNCTION_SUM = "SUM";
  public static final String FUNCTION_MAX = "MAX";
  public static final String FUNCTION_MIN = "MIN";
  public static final String FUNCTION_MOD = "MOD";

  //Arithmetic Operations
  public static final String ARITHMETIC_OPERATION_ADD = "+";
  public static final String ARITHMETIC_OPERATION_SUBTRACT = "-";
  public static final String ARITHMETIC_OPERATION_MULTIPLY = "*";
  public static final String ARITHMETIC_OPERATION_DIVIDE = "/";



  //Values   
  public static final Value VALUE_NULL = new Value("NULL", DATATYPE_NULL);
}