/*********************************************************************
 * Licensed Materials - PropertyImpl of IBM                              *
 *                                                                   *
 * 5724-B88                                                          *
 *                                                                   *
 *  Copyright IBM Corp.  2001, 2002    All Rights Reserved.         *
 *                                                                   *
 * US Government Users Restricted Rights - Use, duplication or       *
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp. *
 *********************************************************************/

package com.ibm.websphere.query.base;

import java.util.ArrayList;
import java.util.List;

/**
	<P>The OrderBy class represents the order by part of a select query in the query framework.
	
	<P>This class contains a list of order by expressions to describe a typical order by clause in
	a query.
 */
public class OrderBy implements IOrderBy
{
  private List orderByExpressions = new ArrayList();
  /**
  	Creates a new OrderBy instance, default constructor.
   */
  public OrderBy()
  {
    super();
  }
  /**
  	Creates a new OrderBy instance with the given array of order by expressions.
   */
  public OrderBy(IOrderByExpression[] orderByExpressions)
  {
    super();
    setOrderByExpressions(orderByExpressions);
  }
  /**
  	Creates a new OrderBy instance with the given order by expression.
   */
  public OrderBy(IOrderByExpression orderByExpression)
  {
    super();
    setOrderByExpression(orderByExpression);
  }
  /**
  	Adds an order by expression to the order by expression vector.
   */
  public void addOrderByExpression(IOrderByExpression orderByExpression)
  {
    orderByExpressions.add(orderByExpression);
  }
  /**
  	Builds a query string for the order by.
   */
  public String buildString(ISelectQueryCallback builder) throws QueryException
  {
    return builder.buildOrderBy(this);
  }
  public void buildString(ISelectQueryCallback builder, StringBuffer sb) throws QueryException
  {
    builder.buildOrderBy(this, sb);
  }
  /**
  	Tests for equality with the given object.
   */
  public boolean equals(Object o)
  {
    boolean eq = true;

    if (o instanceof OrderBy)
    {
      OrderBy ob = (OrderBy) o;

      eq = orderByExpressions.equals(ob.orderByExpressions);
    }
    else
    {
      eq = false;
    }

    return eq;
  }
  /**
  	Returns the order by expressions as an array.
   */
  public IOrderByExpression[] getOrderByExpressions()
  {
    IOrderByExpression oa[] = new IOrderByExpression[orderByExpressions.size()];

    for (int i = 0; i < orderByExpressions.size(); i++)
    {
      oa[i] = (IOrderByExpression) (orderByExpressions.get(i));
    }

    return oa;
  }
  /**
  	Computes a hash code for the order by.
   */
  public int hashCode()
  {
    int hashCode = 0;

    for (int i = 0; i < orderByExpressions.size(); i++)
    {
      hashCode = hashCode ^ orderByExpressions.get(i).hashCode();
    }

    return hashCode;
  }
  /**
  	Sets the order by expression of the order by.
   */
  public void setOrderByExpression(IOrderByExpression newOrderByExpression)
  {
    orderByExpressions.clear();

    orderByExpressions.add(newOrderByExpression);
  }
  /**
  	Sets the order by expressions of the order by.
   */
  public void setOrderByExpressions(IOrderByExpression[] newOrderByExpressions)
  {
    orderByExpressions.clear();

    for (int i = 0; i < newOrderByExpressions.length; i++)
    {
      orderByExpressions.add(newOrderByExpressions[i]);
    }
  }
}
