/*********************************************************************
 * Licensed Materials - Property of IBM                              *
 *                                                                   *
 * 5724-B88                                                          *
 *                                                                   *
 *  Copyright IBM Corp.  2001, 2002    All Rights Reserved.         *
 *                                                                   *
 * US Government Users Restricted Rights - Use, duplication or       *
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp. *
 *********************************************************************/

package com.ibm.websphere.query.examples;




import com.ibm.websphere.query.callbacks.*;import com.ibm.websphere.query.base.*;import java.util.*;
import com.sun.jndi.ldap.ctl.SortKey;public class LdapQueryGenerator {
  private final static String copyright = "Licensed Materials - Property of IBM\n\n5724-B88\n\n Copyright IBM Corp.  2001, 2002";

 	UtilSimpleUI    ui        = new UtilSimpleUI();


/**
 * MyRunnable constructor comment.
 */
public LdapQueryGenerator() {
	super();
}
/**
 * Starts the application.
 * @param args an array of command-line arguments
 */
public static void main(java.lang.String[] args) {
boolean       loopControl = true;
UtilSimpleUI  ui          = new UtilSimpleUI();
LdapQueryGenerator demo 	= new LdapQueryGenerator();

System.out.println("");
System.out.println("My Simple SQL Query Generation");
System.out.println("");

while (loopControl) {
  System.out.println("");
  System.out.println("Selections:");
  System.out.println("0. Exit");
  System.out.println("1. Build Ldap query string without mapping (simplest)");
  System.out.println("2. Build Ldap query string with mapping");
  switch (ui.getInteger("Enter your selection:")) {
	case 0: loopControl = false;    break;
	case 1: demo.buildLdapQueryStringNoMapping();      break;
	case 2: demo.buildLdapQueryStringWithMapping();      break;
	}
  }


System.out.println("Bye.");

}
/**
 * Insert the method's description here.
 * Creation date: (2/26/2001 12:43:12 PM)
 */
public void buildLdapQuery1(boolean mapping) {
	// create a query object
	SelectQuery q = new SelectQuery();

	Attribute a = new Attribute("LayoutId");
	Operator o = new Operator(Constants.OPERATOR_GT);
	Value v = new Value("000200", Constants.DATATYPE_CHAR);
	Condition condition = new Condition(a, o, v);

	q.setPredicate(condition);

	Hashtable h = null;
	if (mapping == true) {
		// prepare the mapping
		h = new Hashtable();
		h.put("LayoutId", "SCHEMA.LID");
		h.put("Description", "SCHEMA.DESC");
		h.put("LayoutName", "SCHEMA.LNAME");
	}
	
	// build the sql query string using the sql callback
	try {
		String s=q.buildPredicateString(new LdapSelectQueryCallback(h));
		System.out.println("Generated Ldap query string:\n\t" + s);
	}
	catch (QueryException e) {
		System.out.println(e.getMessage());
	}
	
}/**
 * Insert the method's description here.
 * Creation date: (2/26/2001 12:43:12 PM)
 */          
public void buildLdapQuery2(boolean mapping) {
	// create a query object
	SelectQuery q = new SelectQuery();

	// construct an condition
	Attribute a = new Attribute("LayoutId");
	Operator o = new Operator(Constants.OPERATOR_EQ);
	Value v = new Value("000200", Constants.DATATYPE_CHAR);
	
	Condition condition = new Condition(a, o, v);

	// construct another condition
	Attribute a2 = new Attribute("Description");
	Operator o2 = new Operator(Constants.OPERATOR_EQ);
	Value v2 = new Value("Three column layout", Constants.DATATYPE_CHAR);
	
	Condition condition2 = new Condition(a2, o2, v2);

	// build predicate
	Operator o3 = new Operator(Constants.OPERATOR_OR);
	PredicateBase pb[] = new PredicateBase[2];
	pb[0] = condition;
	pb[1] = condition2;
	Predicate p = new Predicate(o3, pb);
	
	q.setPredicate(p);

	Hashtable h = null;
	if (mapping == true) {
		// prepare the mapping
		h = new Hashtable();
		h.put("LayoutId", "SCHEMA.LID");
		h.put("Description", "SCHEMA.DESC");
		h.put("LayoutName", "SCHEMA.LNAME");
	}
	
	// build the sql query string using the sql callback
	try {
		String s=q.buildPredicateString(new LdapSelectQueryCallback(h));
		System.out.println("Generated Ldap query string:\n\t" + s);
	}
	catch (QueryException e) {
		System.out.println(e.getMessage());
	}
}/**
 * Insert the method's description here.
 * Creation date: (2/26/2001 12:43:12 PM)
 */    
public void buildLdapQuery3(boolean mapping) {
	// create a query object
	SelectQuery q = new SelectQuery();

	// construct an condition
	Attribute a = new Attribute("LayoutId");
	Operator o = new Operator(Constants.OPERATOR_GT);
	Value v = new Value("000200", Constants.DATATYPE_VARCHAR);
	
	Condition condition = new Condition(a, o, v);

	// construct another condition
	Attribute a2 = new Attribute("Description");
	Operator o2 = new Operator(Constants.OPERATOR_NEQ);
	Value v2 = new Value("Three column layout", Constants.DATATYPE_CHAR);
	
	Condition condition2 = new Condition(a2, o2, v2);

	// construct another condition
	Attribute a3 = new Attribute("LayoutName");
	Operator o3 = new Operator(Constants.OPERATOR_IN);
	Value v31 = new Value("Tab", Constants.DATATYPE_CHAR);
	Value v32 = new Value("Column", Constants.DATATYPE_CHAR);
	Value v33 = new Value("Table", Constants.DATATYPE_CHAR);
	
	Condition condition3 = new Condition(a3, o3, v31);
	condition3.addRightOperand(v32);
	condition3.addRightOperand(v33);

	// build predicate
	Operator o4 = new Operator(Constants.OPERATOR_AND);
	PredicateBase pb[] = new PredicateBase[3];
	pb[0] = condition;
	pb[1] = condition2;
	pb[2] = condition3;
	Predicate p = new Predicate(o4, pb);
	
	q.setPredicate(p);

	Hashtable h = null;
	if (mapping == true) {
		// prepare the mapping
		h = new Hashtable();
		h.put("LayoutId", "SCHEMA.LID");
		h.put("Description", "SCHEMA.DESC");
		h.put("LayoutName", "SCHEMA.LNAME");
	}
	
	// build the sql query string using the sql callback
	try {
		String s=q.buildPredicateString(new LdapSelectQueryCallback(h));
		System.out.println("Generated Ldap query string:\n\t" + s);
	}
	catch (QueryException e) {
		System.out.println(e.getMessage());
	}
	
}/**
 * Insert the method's description here.
 * Creation date: (2/26/2001 12:43:12 PM)
 */   
public void buildLdapQuery4(boolean mapping) {
	// create a query object
	SelectQuery q = new SelectQuery();

	// construct an condition
	Attribute a = new Attribute("LayoutId");
	Operator o = new Operator(Constants.OPERATOR_EQ);
	Value v = new Value("000200", Constants.DATATYPE_CHAR);
	
	Condition condition = new Condition(a, o, v);

	// construct another condition
	Attribute a2 = new Attribute("LayoutName");
	Operator o2 = new Operator(Constants.OPERATOR_EQ);
	Value v2 = new Value("Tab", Constants.DATATYPE_CHAR);
	
	Condition condition2 = new Condition(a2, o2, v2);

	// construct another condition
	Attribute a3 = new Attribute("LayoutId");
	Operator o3 = new Operator(Constants.OPERATOR_BTW);
	Value v31 = new Value("30", Constants.DATATYPE_CHAR);
	Value v32 = new Value("50", Constants.DATATYPE_CHAR);
	
	Condition condition3 = new Condition(a3, o3, v31);
	condition3.addRightOperand(v32);
	
	// build predicate
	Operator o4 = new Operator(Constants.OPERATOR_AND);
	PredicateBase pb[] = new PredicateBase[2];
	pb[0] = condition;
	pb[1] = condition2;
	Predicate p = new Predicate(o4, pb);
	
	Operator o5 = new Operator(Constants.OPERATOR_OR);
	PredicateBase pb2[] = new PredicateBase[2];
	pb2[0] = p;
	pb2[1] = condition3;
	Predicate p2 = new Predicate(o5, pb2);

	q.setPredicate(p2);

	Hashtable h = null;
	if (mapping == true) {
		// prepare the mapping
		h = new Hashtable();
		h.put("LayoutId", "SCHEMA.LID");
		h.put("Description", "SCHEMA.DESC");
		h.put("LayoutName", "SCHEMA.LNAME");
	}
	
	// build the sql query string using the sql callback
	try {
		String s=q.buildPredicateString(new LdapSelectQueryCallback(h));
		System.out.println("Generated Ldap query string:\n\t" + s);
	}
	catch (QueryException e) {
		System.out.println(e.getMessage());
	}
	
}/**
 * Insert the method's description here.
 * Creation date: (2/26/2001 12:43:12 PM)
 */    
public void buildLdapQuery5(boolean mapping) {
	// create a query object
	SelectQuery q = new SelectQuery();

	// construct an condition
	Attribute a = new Attribute("CityList");
	Operator o = new Operator(Constants.OPERATOR_MVANY);
	Value v = new Value("raleigh", Constants.DATATYPE_CHAR);
	Value v2 = new Value("san francisco", Constants.DATATYPE_CHAR);
	Value v3 = new Value("new york", Constants.DATATYPE_CHAR);
	
	Condition condition = new Condition(a, o, v);
	condition.addRightOperand(v2);
	condition.addRightOperand(v3);

	q.setPredicate(condition);

	Hashtable h = null;
	if (mapping == true) {
		// prepare the mapping
		h = new Hashtable();
		h.put("LayoutId", "SCHEMA.LID");
		h.put("Description", "SCHEMA.DESC");
		h.put("LayoutName", "SCHEMA.LNAME");
		String sa[] = {"PERSCITY","CITY","PERSCITY.PID","PERSONNEL.PID"};
		h.put("CityList", sa);
	}
	
	// build the sql query string using the sql callback
	try {
		String s=q.buildPredicateString(new LdapSelectQueryCallback(h));
		System.out.println("Generated Ldap query string:\n\t" + s);
	}
	catch (QueryException e) {
		System.out.println(e.getMessage());
	}

}/**
 * Insert the method's description here.
 * Creation date: (2/26/2001 12:43:12 PM)
 */  
public void buildLdapQuery6(boolean mapping) {
	// create a query object
	SelectQuery q = new SelectQuery();

	// construct an operand
	Attribute a = new Attribute("CityList");
	Operator o = new Operator(Constants.OPERATOR_MVALL);
	Value v = new Value("raleigh", Constants.DATATYPE_CHAR);
	Value v2 = new Value("san francisco", Constants.DATATYPE_CHAR);
	
	Condition operand = new Condition(a, o, v);
	operand.addRightOperand(v2);

	q.setPredicate(operand);

	Hashtable h = null;
	if (mapping == true) {
		// prepare the mapping
		h = new Hashtable();
		h.put("LayoutId", "SCHEMA.LID");
		h.put("Description", "SCHEMA.DESC");
		h.put("LayoutName", "SCHEMA.LNAME");
		String sa[] = {"PERSCITY","CITY","PERSCITY.PID","PERSONNEL.PID"};
		h.put("CityList", sa);
	}
	
	// build the sql query string using the sql callback
	try {
		String s=q.buildPredicateString(new LdapSelectQueryCallback(h));
		System.out.println("Generated Ldap query string:\n\t" + s);
	}
	catch (QueryException e) {
		System.out.println(e.getMessage());
	}

}/**
 * Insert the method's description here.
 * Creation date: (2/26/2001 12:43:12 PM)
 */  
public void buildLdapQuery7(boolean mapping) {
	// create a query object
	SelectQuery q = new SelectQuery();

	Attribute a = new Attribute("LayoutId");
	Operator o = new Operator(Constants.OPERATOR_EQ);
	Value v = new Value("000200", Constants.DATATYPE_CHAR);
	Function f = new Function(Constants.FUNCTION_UPPER, a);

	Condition condition = new Condition(f, o, v);

	q.setPredicate(condition);

	Hashtable h = null;
	if (mapping == true) {
		// prepare the mapping
		h = new Hashtable();
		h.put("LayoutId", "SCHEMA.LID");
		h.put("Description", "SCHEMA.DESC");
		h.put("LayoutName", "SCHEMA.LNAME");
	}
	
	// build the sql query string using the sql callback
	try {
		String s=q.buildPredicateString(new LdapSelectQueryCallback(h));
		System.out.println("Generated Ldap query string:\n\t" + s);
	}
	catch (QueryException e) {
		System.out.println(e.getMessage());
	}
	
}/**
 * Insert the method's description here.
 * Creation date: (2/26/2001 12:43:12 PM)
 */   
public void buildLdapQuery8(boolean mapping) {
	// create a query object
	SelectQuery q = new SelectQuery();

	Attribute a = new Attribute("LayoutId");
	Operator o = new Operator(Constants.OPERATOR_EQ);
	Value v = new Value("Test", Constants.DATATYPE_CHAR);
	Function f = new Function(Constants.FUNCTION_UPPER, new Function(Constants.FUNCTION_LOWER,v));

	Condition condition = new Condition(a, o, f);

	q.setPredicate(condition);

	Hashtable h = null;
	if (mapping == true) {
		// prepare the mapping
		h = new Hashtable();
		h.put("LayoutId", "SCHEMA.LID");
		h.put("Description", "SCHEMA.DESC");
		h.put("LayoutName", "SCHEMA.LNAME");
	}
	
	// build the sql query string using the sql callback
	try {
		String s=q.buildPredicateString(new LdapSelectQueryCallback(h));
		System.out.println("Generated Ldap query string:\n\t" + s);
	}
	catch (QueryException e) {
		System.out.println(e.getMessage());
	}
	
}/**
 * Insert the method's description here.
 * Creation date: (2/26/2001 12:43:12 PM)
 */  
public void buildLdapQuery9(boolean mapping) {
	// create a query object
	SelectQuery q = new SelectQuery();

	// create an order by expression
	Attribute a = new Attribute("UID");
	Operator o = new Operator(Constants.OPERATOR_ASC);
	OrderByExpression oe = new OrderByExpression(o, a);

	// create an order by expression
	Attribute a2 = new Attribute("TelephoneNumber");
	Operator o2 = new Operator(Constants.OPERATOR_DES);
	OrderByExpression oe2 = new OrderByExpression(o2, a2);
	
	OrderBy orderBy = new OrderBy(oe);
	orderBy.addOrderByExpression(oe2);

	q.setOrderBy(orderBy);

	// create a predicate
	Attribute a3 = new Attribute("UID");
	Operator o3 = new Operator(Constants.OPERATOR_EQ);
	Value v3 = new Value("000200", Constants.DATATYPE_CHAR);
	
	Condition condition = new Condition(a3, o3, v3);

	q.setPredicate(condition);

	Hashtable h = null;
	if (mapping == true) {
		// prepare the mapping
		h = new Hashtable();
		h.put("Employee ID", "SCHEMA.UID");
		h.put("Telephone", "SCHEMA.TEL");
	}
	
	// build the sql query string using the sql callback
	try {
		LdapSelectQueryCallback builder = new LdapSelectQueryCallback(h);
		String s=q.buildString(builder);
		System.out.println("Generated Ldap query string:\n\t" + s);
		
		//
		//
		//
		
		String [] sortStrings = builder.getSortStrings();
		if (sortStrings  != null) {
	        SortKey[] sortKeys = new SortKey[sortStrings.length/2]; 
			for (int i=0;i<sortStrings.length;i=i+2) {
				String attribute = sortStrings[i];
				String sortOrder = sortStrings[i+1];
				boolean bSortOrder = true;
				if (sortOrder == LdapSelectQueryCallback.LDAP_QUERY_ORDERBYDES)
					bSortOrder = false;	
	        	SortKey sortKey = new SortKey(attribute, bSortOrder, null);
	        	sortKeys[i/2] = sortKey;
	        	System.out.println(attribute + " " + sortOrder + " " + bSortOrder);
			}
			
	   }	
	}
	catch (QueryException e) {
		System.out.println(e.getMessage());
	}
	
}/**
 * Insert the method's description here.
 * Creation date: (2/26/2001 12:33:15 PM)
 */                                                
       
public void buildLdapQueryStringNoMapping() {
	boolean       loopControl = true;
	boolean		mapping = false;
	UtilSimpleUI  ui          = new UtilSimpleUI();

	while (loopControl) {
	  System.out.println("");
	  System.out.println("Build an sql query string without mapping:");
	  System.out.println("0. Exit");
	  System.out.println("1. (a GT 'x')");
	  System.out.println("2. (a EQ 'x') and (b EQ 'y')");
	  System.out.println("3. (a GT 'x') and (b NEQ 'y') and (c IN 'z' 'p' 'q')");
	  System.out.println("4. ((a EQ 'x') and (b GEQ 'y')) or (a BETWEEN 'x' 'z')");
	  System.out.println("5. (a MVANY 'x, y, z')");
	  System.out.println("6. (a MVALL 'x, y')");
	  System.out.println("7. (UPPER(a) EQ 'X')");
	  System.out.println("8. (a EQ UPPER(LOWER('X')))");
	  System.out.println("9. (ORDER BY a ASC, b DESC)");
	  System.out.println("10.(a GT 'x')");
	  switch (ui.getInteger("Enter your selection:")) {
		case 0: loopControl = false;    break;
		case 1: 
			buildLdapQuery1(mapping);
			break;
		case 2: 
			buildLdapQuery2(mapping);
			break;
		case 3: 
			buildLdapQuery3(mapping);
			break;
		case 4: 
			buildLdapQuery4(mapping);
			break;
		case 5: 
			buildLdapQuery5(mapping);
			break;
		case 6: 
			buildLdapQuery6(mapping);
			break;
		case 7: 
			buildLdapQuery7(mapping);
			break;
		case 8: 
			buildLdapQuery8(mapping);
			break;
		case 9: 
			buildLdapQuery9(mapping);
			break;
		}
	}
}/**
 * Insert the method's description here.
 * Creation date: (2/26/2001 12:33:15 PM)
 */      public void buildLdapQueryStringWithMapping() {
	boolean       loopControl = true;
	boolean		mapping = true;
	UtilSimpleUI  ui          = new UtilSimpleUI();

	while (loopControl) {
	  System.out.println("");
	  System.out.println("Build an sql query string with mapping:");
	  System.out.println("0. Exit");
	  System.out.println("1. (a EQ 'x')");
	  System.out.println("2. (a EQ 'x') and (b EQ 'y')");
	  System.out.println("3. (a GT 'x') and (b NEQ 'y') and (c IN 'z' 'p' 'q')");
	  System.out.println("4. ((a EQ 'x') and (b GEQ 'y')) or (a BETWEEN 'x' 'z')");
	  System.out.println("5. (a MVANY 'x, y, z')");
	  System.out.println("6. (a MVALL 'x, y')");
	  System.out.println("7. (UPPER(a) EQ 'X')");
	  System.out.println("8. (a EQ UPPER(LOWER('X')))");
	  System.out.println("9. (ORDER BY a ASC, b DESC)");
	  switch (ui.getInteger("Enter your selection:")) {
		case 0: loopControl = false;    break;
		case 1: 
			buildLdapQuery1(mapping);
			break;
		case 2: 
			buildLdapQuery2(mapping);
			break;
		case 3: 
			buildLdapQuery3(mapping);
			break;
		case 4: 
			buildLdapQuery4(mapping);
			break;
		case 5: 
			buildLdapQuery5(mapping);
			break;
		case 6: 
			buildLdapQuery6(mapping);
			break;
		case 7: 
			buildLdapQuery7(mapping);
			break;
		case 8: 
			buildLdapQuery8(mapping);
			break;
		case 9: 
			buildLdapQuery9(mapping);
			break;
		}
	}
}}