<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:xalan="http://xml.apache.org/xslt" xmlns:base="http://www.ibm.com/websphere/appserver/schemas/6.0/ibm-portal-base.xsd" xmlns:portal="http://www.ibm.com/websphere/appserver/schemas/6.0/ibm-portal-topology.xsd">
	<xsl:output method="xml" encoding="UTF-8" indent="yes" xalan:indent-amount="2" />

	<xsl:strip-space elements="*" />

	<!--======================================================================-->
	<!-- This file contains an XSLT transformation stylesheet which           -->
	<!-- constructs a result tree from a number of XML sources by filtering   -->
	<!-- reordering and adding arbitrary structure. This file is              -->
	<!-- automatically generated by the XML Mapper tool from IBM WebSphere    -->
	<!-- Studio Workbench.                                                    -->
	<!--======================================================================-->

	<xsl:param name="content-root" select="'wps.content.root'" />
	<xsl:param name="unique-identifier" />

	<!--======================================================================-->
	<!--                          The Root Element                            -->
	<!-- The "Root Element" section specifies which template will be          -->
	<!-- invoked first thus determining the root element of the result tree.  -->
	<!--======================================================================-->
	<!-- portal:ibm-portal-topology -->
	<xsl:template match="/">
		<portal:ibm-portal-topology>
			<!-- @appID -->
			<xsl:attribute name="appID">
				<xsl:text>com.ibm.etools.portaledit</xsl:text>
			</xsl:attribute>
			<!-- @version -->
			<xsl:attribute name="version">
				<xsl:text>0.9</xsl:text>
			</xsl:attribute>
			<!-- portal:title -->
			<portal:title>
				<base:nls-string />
			</portal:title>
			<!-- portal:about-page or portal:PAA-ref -->
			<portal:about-page></portal:about-page>
			<!-- ###portal:requires-->
			<!-- portal:application-tree portal:layout-tree portal:navigation-element -->
			<xsl:apply-templates select="request" />
		</portal:ibm-portal-topology>
	</xsl:template>

	<!--======================================================================-->
	<!--                         Remaining Templates                          -->
	<!-- The remaining section defines the template rules. The last template  -->
	<!-- rule is a generic identity transformation used for moving complete   -->
	<!-- tree fragments from an input source to the result tree.              -->
	<!--======================================================================-->
	<!-- portal:application-tree portal:layout-tree portal:navigation-element -->
	<xsl:template match="request">
		<!-- portal:application-tree -->
		<portal:application-tree>
			<!-- @uniqueName -->
			<xsl:attribute name="uniqueName">
				<xsl:value-of select="concat('application-tree', '.', generate-id(), '.', $unique-identifier)" />
			</xsl:attribute>
			<!-- ###portal:title -->
			<!-- ###portal:description -->
			<!-- portal:application-tree[@uniqueName='wps.any'] -->
			<portal:application-tree>
				<!-- @uniqueName -->
				<xsl:attribute name="uniqueName">
					<xsl:text>wps.any</xsl:text>
				</xsl:attribute>
				<!-- ###portal:title -->
				<!-- ###portal:description -->
				<!-- ###portal:application-tree -->
				<!-- portal:application-element -->
				<xsl:apply-templates select="portal/global-settings" />
			</portal:application-tree>
			<!-- portal:application-tree[@uniqueName='wps.portletentity'] -->
			<portal:application-tree>
				<!-- @uniqueName -->
				<xsl:attribute name="uniqueName">
					<xsl:text>wps.portletentity</xsl:text>
				</xsl:attribute>
				<!-- ###portal:title -->
				<!-- ###portal:description -->
				<!-- ###portal:application-tree -->
				<!-- portal:application-element -->
				<xsl:apply-templates select="portal/web-app/portlet-app/portlet" />
			</portal:application-tree>
			<!-- portal:application-tree[@uniqueName='wps.skin'] -->
			<portal:application-tree>
				<!-- @uniqueName -->
				<xsl:attribute name="uniqueName">
					<xsl:text>wps.skin</xsl:text>
				</xsl:attribute>
				<!-- ###portal:title -->
				<!-- ###portal:description -->
				<!-- ###portal:application-tree -->
				<!-- portal:application-element -->
				<xsl:apply-templates select="portal/skin" />
			</portal:application-tree>
			<!-- portal:application-tree[@uniqueName='wps.theme'] -->
			<portal:application-tree>
				<!-- @uniqueName -->
				<xsl:attribute name="uniqueName">
					<xsl:text>wps.theme</xsl:text>
				</xsl:attribute>
				<!-- ###portal:title -->
				<!-- ###portal:description -->
				<!-- ###portal:application-tree -->
				<!-- portal:application-element -->
				<xsl:apply-templates select="portal/theme" />
			</portal:application-tree>
			<!-- portal:application-tree[@uniqueName='wps.label'] -->
			<portal:application-tree>
				<!-- @uniqueName -->
				<xsl:attribute name="uniqueName">
					<xsl:text>wps.label</xsl:text>
				</xsl:attribute>
				<!-- ###portal:title -->
				<!-- ###portal:description -->
				<!-- ###portal:application-tree -->
				<!-- portal:application-element -->
				<xsl:apply-templates select="portal/content-node[@uniquename=$content-root]">
					<xsl:with-param name="tree-type" select="'label'" />
				</xsl:apply-templates>
			</portal:application-tree>
			<!-- portal:application-tree[@uniqueName='wps.urlLink'] -->
			<portal:application-tree>
				<!-- @uniqueName -->
				<xsl:attribute name="uniqueName">
					<xsl:text>wps.urlLink</xsl:text>
				</xsl:attribute>
				<!-- ###portal:title -->
				<!-- ###portal:description -->
				<!-- ###portal:application-tree -->
				<!-- portal:application-element -->
				<xsl:apply-templates select="portal/content-node[@uniquename=$content-root]">
					<xsl:with-param name="tree-type" select="'urlLink'" />
				</xsl:apply-templates>
			</portal:application-tree>
			<!-- portal:application-tree[@uniqueName='wps.wire'] -->
			<portal:application-tree>
				<!-- @uniqueName -->
				<xsl:attribute name="uniqueName">
					<xsl:text>wps.wire</xsl:text>
				</xsl:attribute>
				<xsl:if test="portal/content-node[@type='page']/wire">
					<xsl:for-each select="portal/content-node[@type='page']/wire" >
						<!-- portal:application-element -->
						<xsl:call-template name="wires" />
					</xsl:for-each>
				</xsl:if>
			</portal:application-tree>
			<!-- ###portal:application-element -->
		</portal:application-tree>

		<!-- portal:layout-tree -->
		<portal:layout-tree>
			<!-- ###portal:title -->
			<!-- ###portal:description -->
			<!-- ###portal:layout-tree -->
			<!-- portal:layout-element -->
			<xsl:apply-templates select="portal/content-node[@uniquename=$content-root]">
				<xsl:with-param name="tree-type" select="'page'" />
			</xsl:apply-templates>
		</portal:layout-tree>
		<!-- portal:navigation-element -->
		<xsl:apply-templates select="portal/content-node[@uniquename=$content-root]" mode="navigation" />
	</xsl:template>

	<xsl:template name="wires" >
		<!-- This should only be applied to wires who's users are 'anonymous portal user' -->
		<xsl:if test="@user = 'anonymous portal user'">
			<portal:application-element>
				<!-- @uniqueName -->
				<xsl:call-template name="uniqueName" />				
				<!-- @type -->
				<xsl:attribute name="type">
					<xsl:value-of select="'wire'" />
				</xsl:attribute>
				<!-- portal:title -->
				<xsl:call-template name="title" />
				<!-- portal:parameter[portal:name='immediate-switch'] -->
				<xsl:call-template name="immediate-switch" />	
				<!-- portal:parameter[portal:name='objectid'] -->
				<xsl:call-template name="objectid" />
				<!-- portal:parameter[portal:name='ordinal'] -->
				<xsl:call-template name="ordinal" />
			
				<!-- portal:parameter[portal:name='source-action'] -->
				<xsl:call-template name="source-action" />
				<!-- portal:parameter[portal:name='source-param'] -->
				<xsl:call-template name="source-param" />	
				<!-- portal:parameter[portal:name='source-property'] -->
				<xsl:call-template name="source-property" />
				<!-- portal:parameter[portal:name='source-portletinstanceref'] -->
				<xsl:call-template name="source-portletinstanceref" />

				<!-- portal:parameter[portal:name='target-action'] -->
				<xsl:call-template name="target-action" />
				<!-- portal:parameter[portal:name="target-param'] -->
				<xsl:call-template name="target-param" />
				<!-- portal:parameter[portal:name='target-property'] -->
				<xsl:call-template name="target-property" />
				<!-- portal:parameter[portal:name="target-portletinstanceref"] -->
				<xsl:call-template name="target-portletinstanceref" />
			
				<!-- portal:parameter[portal:name="user"] -->
				<xsl:call-template name="user" />
			</portal:application-element>
		</xsl:if>
	</xsl:template>

	<!-- portal:application-element[@type='any'] -->
	<xsl:template match="global-settings">
		<!-- poratl:application-element -->
		<portal:application-element>
			<!-- @uniqueName -->
			<xsl:attribute name="uniqueName">
				<xsl:text>wps.any.globalsettings</xsl:text>
			</xsl:attribute>
			<!-- @type -->
			<xsl:attribute name="type">
				<xsl:text>any</xsl:text>
			</xsl:attribute>
			<!-- ###@keyword -->
			<!-- ###@parentTree -->
			<!-- ###portal:resource-link -->
			<!-- portal:title -->
			<xsl:call-template name="global-settings-title" />
			<!-- ###portal:description -->
			<!-- portal:parameter[portal:name='language'] -->
			<xsl:call-template name="language" />
			<!-- portal:parameter[portal:name='default-language'] -->
			<xsl:call-template name="default-language" />
		</portal:application-element>
	</xsl:template>
	
	<!-- portal:application-element[@type='portletentity'] -->
	<xsl:template match="portlet">
		<!-- portal:application-element -->
		<portal:application-element>
			<!-- @uniqueName -->
			<xsl:call-template name="uniqueName" />
			<!-- @type -->
			<xsl:attribute name="type">
				<xsl:text>portletentity</xsl:text>
			</xsl:attribute>
			<!-- ###@keyword -->
			<!-- ###@parentTree -->
			<!-- ###portal:resource-link -->
			<!-- portal:title -->
			<xsl:call-template name="title" />
			<!-- portal:description -->
			<xsl:call-template name="description" />
			<!-- portal:parameter[portal:name='active'] -->
			<xsl:call-template name="active" />
			<!-- portal:parameter[portal:name='uniquename'] -->
			<xsl:call-template name="uniquename" />
			<!-- portal:parameter[portal:name='objectid'] -->
			<xsl:call-template name="objectid" />
			<!-- portal:parameter[portal:name='web-app-id'] -->
			<xsl:call-template name="web-app-uid">
				<xsl:with-param name="web-app-uid" select="../../@uid" />
			</xsl:call-template>
			<!-- portal:parameter[portal:name='portlet-app-id'] -->
			<xsl:call-template name="portlet-app-uid">
				<xsl:with-param name="portlet-app-uid" select="../@uid" />
			</xsl:call-template>
			<!-- portal:parameter[portal:name='portlet-name'] -->
			<xsl:call-template name="portlet-name" />
		</portal:application-element>
	</xsl:template>

	<!-- portal:application-element[@type='skin'] -->
	<xsl:template match="skin">
		<!-- portal:application-element -->
		<portal:application-element>
			<!-- @uniqueName -->
			<xsl:call-template name="uniqueName" />
			<!-- @type -->
			<xsl:attribute name="type">
				<xsl:text>skin</xsl:text>
			</xsl:attribute>
			<!-- ###@keyword -->
			<!-- ###@parentTree -->
			<!-- ###portal:resource-link -->
			<!-- portal:title -->
			<xsl:call-template name="title" />
			<!-- portal:description -->
			<xsl:call-template name="description" />
			<!-- portal:parameter[portal:name='active'] -->
			<xsl:call-template name="active" />
			<!-- portal:parameter[portal:name='default'] -->
			<xsl:call-template name="default" />
			<!-- portal:parameter[portal:name='uniquename'] -->
			<xsl:call-template name="uniquename" />
			<!-- portal:parameter[portal:name='objectid'] -->
			<xsl:call-template name="objectid" />
			<!-- portal:parameter[portal:name='resourceroot'] -->
			<xsl:call-template name="resourceroot" />
		</portal:application-element>
	</xsl:template>

	<!-- portal:application-element[@type='theme'] -->
	<xsl:template match="theme">
		<!-- portal:application-element -->
		<portal:application-element>
			<!-- @uniqueName -->
			<xsl:call-template name="uniqueName" />
			<!-- @type -->
			<xsl:attribute name="type">
				<xsl:text>theme</xsl:text>
			</xsl:attribute>
			<!-- ###@keyword -->
			<!-- ###@parentTree -->
			<!-- ###portal:resource-link -->
			<!-- portal:title -->
			<xsl:call-template name="title" />
			<!-- portal:description -->
			<xsl:call-template name="description" />
			<!-- portal:parameter[portal:name='active'] -->
			<xsl:call-template name="active" />
			<!-- portal:parameter[portal:name='default'] -->
			<xsl:call-template name="default" />
			<!-- portal:parameter[portal:name='defaultskinref'] -->
			<xsl:call-template name="defaultskinref" />
			<!-- portal:parameter[portal:name='uniquename'] -->
			<xsl:call-template name="uniquename" />
			<!-- portal:parameter[portal:name='objectid'] -->
			<xsl:call-template name="objectid" />
			<!-- portal:parameter[portal:name='resourceroot'] -->
			<xsl:call-template name="resourceroot" />
			<!-- portal:parameter[portal:name='allowed-skin'] -->
			<xsl:call-template name="allowed-skin" />
		</portal:application-element>
	</xsl:template>

	<xsl:template match="content-node">
		<xsl:param name="tree-type"/>
		<xsl:choose>
			<xsl:when test="($tree-type='label' and @type='label') or ($tree-type='urlLink' and (@type='internal-url' or @type='external-url'))">
				<!-- portal:application-element -->
				<portal:application-element>
				<!-- @uniqueName -->
				<xsl:call-template name="uniqueName" />				
				<!-- @type -->
				<xsl:attribute name="type">
					<xsl:value-of select="$tree-type" />
				</xsl:attribute>
				<!-- portal:title -->
				<xsl:call-template name="title" />
				<!-- portal:description -->
				<xsl:call-template name="description" />
				<!-- portal:parameter[portal:name='active'] -->
				<xsl:call-template name="active" />
				<!-- portal:parameter[portal:name='uniquename'] -->
				<xsl:call-template name="uniquename" />
				<!-- portal:parameter[portal:name='objectid'] -->
				<xsl:call-template name="objectid" />
				<!-- portal:parameter[portal:name='ordinal'] -->
				<xsl:call-template name="ordinal" />
				<xsl:choose>
						<xsl:when test="@type='label' ">
							<!-- portal:parameter[portal:name='skinref'] -->
							<xsl:call-template name="skinref" />
							<!-- portal:parameter[portal:name='themeref'] -->
							<xsl:call-template name="themref" />
							<!-- portal:parameter[portal:name='supported-markup'] -->
							<xsl:call-template name="supported-markup" />
						</xsl:when>
						<xsl:when test="@type='internal-url' ">
							<!-- portal:parameter[portal:name='type' -->
							<xsl:call-template name="type-internal" />
							<!-- portal:parameter[portal:name='supported-markup'] -->
							<xsl:call-template name="supported-markup" />
							<!-- portal:parameter[portal:name='url'] @portal:parameter[portal:name='label'] @portal:parameter[portal:name='url-mapping-objectid']-->
							<xsl:call-template name="url-internal" />
						</xsl:when>
						<xsl:when test="@type='external-url' ">
							<!-- portal:parameter[portal:name='type' -->
							<xsl:call-template name="type-external" />
							<!-- portal:parameter[portal:name='supported-markup'] -->
							<xsl:call-template name="supported-markup" />
							<!-- portal:parameter[portal:name='url' -->
							<xsl:call-template name="url-external" />
						</xsl:when>
				</xsl:choose>
				</portal:application-element>
			</xsl:when>			
			<xsl:when test="$tree-type='page'">
				<xsl:if test="@type='page' and (@create-type!='implicit' and access-control/@private!='true')">
					<portal:layout-element>
						<!-- @uniqueName -->
						<xsl:call-template name="uniqueName" />				
						<!-- portal:title -->
						<xsl:call-template name="title" />
						<!-- portal:description -->
						<xsl:call-template name="description" />
						<!-- portal:parameter[portal:name='active'] -->
						<xsl:call-template name="active" />
						<!-- portal:parameter[portal:name='uniquename'] -->
						<xsl:call-template name="uniquename" />
						<!-- portal:parameter[portal:name='objectid'] -->
						<xsl:call-template name="objectid" />
						<!-- portal:parameter[portal:name='ordinal'] -->
						<xsl:call-template name="ordinal" />
						<!-- portal:parameter[portal:name='skinref'] -->
						<xsl:call-template name="skinref" />
						<!-- portal:parameter[portal:name='themeref'] -->
						<xsl:call-template name="themref" />
						<!-- portal:parameter[portal:name='supported-markup'] -->
						<xsl:call-template name="supported-markup" />	
						<!-- portal:parameter[portal:name='allportletsallowed'] -->
						<xsl:call-template name="allportletsallowed" />
						<!-- portal:parameter[portal:name='shareable'] -->
						<xsl:call-template name="shareable" />
						<!-- portal:parameter[portal:name='derivation-parentref'] -->
						<xsl:call-template name="derivation-parentref" />
						<!-- portal:parameter[portal:name='allowed-portlet'] -->
						<xsl:call-template name="allowed-portlet" />
						<!-- portal:parameter[portal:name='bookmarkable'] -->
						<xsl:call-template name="bookmarkable" />
						<!-- portal:parameterp[portal:name='IgnoreAccessControlInCaches'] -->
						<xsl:call-template name="IgnoreAccessControlInCaches" />
						<!-- portal:parameterp[portal:name='remote-cache-expiry'] -->
						<xsl:call-template name="remote-cache-expiry" />
						<!-- portal:parameterp[portal:name='remote-cache-scope'] -->
						<xsl:call-template name="remote-cache-scope" />
						
						<xsl:call-template name="wireref" />
						
						<!-- portal:container -->
						<xsl:choose>
							<xsl:when test="@derivation-parentref">
								<!-- portal:container -->
								<portal:container>
									<!-- @uniqueName -->
									<xsl:attribute name="uniqueName">
										<xsl:value-of select="concat('derivation-container', '.', generate-id(), '.', $unique-identifier)" />
									</xsl:attribute>
									<!-- @type -->
									<xsl:attribute name="type">
										<xsl:text>row</xsl:text>
									</xsl:attribute>
									<!-- portal:parameter[portal:name='derivation-container'] -->
									<portal:parameter>
										<!-- base:name -->
										<base:name>
											<xsl:text>derivation-container</xsl:text>
										</base:name>
										<!-- base:value -->
										<base:value>
											<xsl:value-of select="'true'" />
										</base:value>
									</portal:parameter>
									<xsl:apply-templates select="component" />
								</portal:container>
							</xsl:when>
							<xsl:otherwise>
								<xsl:apply-templates select="component" />
							</xsl:otherwise>
						</xsl:choose>
					</portal:layout-element>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$tree-type='label' and @uniquename='wps.content.root' and not(@type)">
					<portal:application-element>
						<!-- @uniquename -->
						<xsl:call-template name="uniqueName" />
						<!-- @type -->
						<xsl:attribute name="type">
							<xsl:text>label</xsl:text>
						</xsl:attribute>
						<!-- @portal:parameter[portal:name='uniquename'] -->
						<xsl:call-template name="uniquename" />
					</portal:application-element>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
		<!-- portal:application-element[@type='label' or @type='urlLink'] portal:layout-element portal:navigation-element -->
		<!-- only process content nodes for wps.Login, wps.SelfCare and wps.My Portal -->
		<xsl:choose>
			<xsl:when test="@uniquename='wps.content.root'">
				<xsl:apply-templates select="/request/portal/content-node[@uniquename='wps.My Portal']">
						<xsl:sort select="@ordinal" data-type="number" />
						<xsl:with-param name="tree-type" select="$tree-type" />
				</xsl:apply-templates>
				<xsl:apply-templates select="/request/portal/content-node[@uniquename='wps.Login']">
						<xsl:sort select="@ordinal" data-type="number" />
						<xsl:with-param name="tree-type" select="$tree-type" />
				</xsl:apply-templates>
				<xsl:apply-templates select="/request/portal/content-node[@uniquename='wps.Selfcare']">
						<xsl:sort select="@ordinal" data-type="number" />
						<xsl:with-param name="tree-type" select="$tree-type" />
				</xsl:apply-templates>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="objectid" select="@objectid" />
				<xsl:apply-templates select="/request/portal/content-node[@content-parentref=$objectid]">
					<xsl:sort select="@ordinal" data-type="number" />
					<xsl:with-param name="tree-type" select="$tree-type" />
				</xsl:apply-templates>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- portal:navigation-element -->
	<xsl:template match="content-node" mode="navigation">
		<xsl:if test="@type!='page' or (@create-type!='implicit' and access-control/@private!='true')">
			<!-- portal:navigation-element -->
			<portal:navigation-element>
				<xsl:attribute name="uniqueName">
					<xsl:value-of select="concat('navigation-element', '.', generate-id(), '.', $unique-identifier)" />
				</xsl:attribute>
				<!-- @layout-element-ref -->
				<xsl:if test="@type='page'">
					<xsl:call-template name="layout-element-ref" />
				</xsl:if>
				<!-- ###@parentTree -->
				<!-- ###portal:title -->
				<!-- ###portal:description -->
				<!-- portal:navigation-content -->
				<xsl:if test="@type='label' or @type='internal-url' or @type='external-url' or (not(@type) and @uniquename='wps.content.root') ">
					<!-- portal:navigation-content -->
					<portal:navigation-content>
						<xsl:attribute name="uniqueName">
							<xsl:value-of select="concat('navigation-content', '.', generate-id(), '.', $unique-identifier)" />
						</xsl:attribute>
						<!-- @application-element-ref -->
						<xsl:call-template name="application-element-ref" />
						<!-- ###@window-ref -->
					</portal:navigation-content>
				</xsl:if>
				<!-- portal:navigation-element -->
				<!-- only process content nodes for wps.Login, wps.SelfCare and wps.My Portal -->
				<xsl:choose>
					<xsl:when test="@uniquename='wps.content.root'">
						<xsl:apply-templates select="/request/portal/content-node[@uniquename='wps.My Portal']" mode="navigation">
								<xsl:sort select="@ordinal" data-type="number" />
						</xsl:apply-templates>
						<xsl:apply-templates select="/request/portal/content-node[@uniquename='wps.Login']" mode="navigation">
								<xsl:sort select="@ordinal" data-type="number" />
						</xsl:apply-templates>
						<xsl:apply-templates select="/request/portal/content-node[@uniquename='wps.Selfcare']" mode="navigation">
								<xsl:sort select="@ordinal" data-type="number" />
						</xsl:apply-templates>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="objectid" select="@objectid" />
						<xsl:apply-templates select="/request/portal/content-node[@content-parentref=$objectid]" mode="navigation">
							<xsl:sort select="@ordinal" data-type="number" />
						</xsl:apply-templates>
					</xsl:otherwise>
				</xsl:choose>
			</portal:navigation-element>
		</xsl:if>
	</xsl:template>

	<!-- portal:container portal:window -->
	<xsl:template match="component">
		<xsl:choose>
			<xsl:when test="@type='container'">
				<!-- portal:container -->
				<portal:container>
					<!-- @uniqueName -->
					<xsl:call-template name="uniqueName" />
					<!-- @type -->
					<xsl:choose>
						<xsl:when test="@orientation='H'">
							<xsl:attribute name="type">
								<xsl:text>row</xsl:text>
							</xsl:attribute>
						</xsl:when>
						<xsl:when test="@orientation='V'">
							<xsl:attribute name="type">
								<xsl:text>column</xsl:text>
							</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="type">
								<xsl:text>row</xsl:text>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<!-- ###portal:title -->
					<!-- ###portal:description -->
					<!-- portal:parameter[portal:name='active'] -->
					<xsl:call-template name="active" />
					<!-- portal:parameter[portal:name='uniquename'] -->
					<xsl:call-template name="uniquename" />
					<!-- portal:parameter[portal:name='objectid'] -->
					<xsl:call-template name="objectid" />
					<!-- portal:parameter[portal:name='ordinal'] -->
					<xsl:call-template name="ordinal" />
					<!-- portal:parameter[portal:name='skinref'] -->
					<xsl:call-template name="skinref" />
					<!-- portal:parameter[portal:name='deletable'] -->
					<xsl:call-template name="deletable" />
					<!-- portal:parameter[portal:name='modifiable'] -->
					<xsl:call-template name="modifiable" />
					<!-- portal:parameter[portal:name='movable'] -->
					<xsl:call-template name="movable" />
					<!-- portal:parameter[portal:name='nestable'] -->
					<xsl:call-template name="nestable" />
					<!-- portal:parameter[portal:name='shadowref'] -->
					<xsl:call-template name="shadowref" />
					<!-- portal:parameter[portal:name='shadow-parentref'] -->
					<xsl:call-template name="shadow-parentref" />
					<!-- portal:parameter[portal:name='width'] -->
					<xsl:call-template name="width" />
					<!-- portal:container portal:window -->
					<xsl:apply-templates select="component" />
				</portal:container>
			</xsl:when>
			<!-- portal:window" -->
			<xsl:when test="@type='control'">
				<!-- portal:window" -->
				<portal:window>
					<!-- @uniqueName -->
					<xsl:call-template name="uniqueName" />
					<!-- ###portal:title -->
					<!-- ###portal:description -->
					<!-- portal:parameter[portal:name='active'] -->
					<xsl:call-template name="active" />
					<!-- portal:parameter[portal:name='uniquename'] -->
					<xsl:call-template name="uniquename" />
					<!-- portal:parameter[portal:name='objectid'] -->
					<xsl:call-template name="objectid" />
					<!-- portal:parameter[portal:name='ordinal'] -->
					<xsl:call-template name="ordinal" />
					<!-- portal:parameter[portal:name='skinref'] -->
					<xsl:call-template name="skinref" />
					<!-- portal:parameter[portal:name='deletable'] -->
					<xsl:call-template name="deletable" />
					<!-- portal:parameter[portal:name='modifiable'] -->
					<xsl:call-template name="modifiable" />
					<!-- portal:parameter[portal:name='movable'] -->
					<xsl:call-template name="movable" />
					<!-- portal:parameter[portal:name='shadowref'] -->
					<xsl:call-template name="shadowref" />
					<!-- portal:parameter[portal:name='shadow-parentref'] -->
					<xsl:call-template name="shadow-parentref" />
					<!-- ###portal:layout-element-ref -->
					<!-- portal:application-element-ref -->
					<portal:application-element-ref>
						<xsl:choose>
							<xsl:when test="portletinstance">
								<xsl:variable name="portletref" select="portletinstance/@portletref" />
								<xsl:choose>
									<xsl:when test="/request/portal/wsrp-producer/portlet-app/portlet[starts-with(@objectid, $portletref)]">
										<xsl:value-of select="'undefined'" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:apply-templates select="/request/portal/web-app/portlet-app/portlet[starts-with(@objectid, $portletref)]" mode="application-element-ref" />
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="'undefined'" />
							</xsl:otherwise>
						</xsl:choose>
					</portal:application-element-ref>
					<!-- ###portal:is-spot -->
				</portal:window>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<!-- @uniqueName -->
	<xsl:template name="uniqueName">
		<xsl:attribute name="uniqueName">
			<xsl:value-of select="concat(local-name(), '.', generate-id(), '.', $unique-identifier)" />
		</xsl:attribute>
	</xsl:template>

	<!-- portal:title -->
	<xsl:template name="global-settings-title">
		<xsl:choose>
			<xsl:when test="/request/portal/web-app/portlet-app/portlet[@name='Global Settings']">
				<xsl:apply-templates select="/request/portal/web-app/portlet-app/portlet[@name='Global Settings']" mode="global-settings-portlet" />
			</xsl:when>
			<xsl:otherwise>
				<portal:title>
					<base:nls-string />
				</portal:title>
			</xsl:otherwise>
		</xsl:choose>		
	</xsl:template>
	
	<!-- portal:application-element-ref -->
	<xsl:template match="/request/portal/web-app/portlet-app/portlet" mode="global-settings-portlet">
		<!-- portal:title -->
		<xsl:call-template name="title" />
	</xsl:template>
	
	<!-- portal:title -->
	<xsl:template name="title">
		<!-- portal:title -->
		<xsl:choose>
			<xsl:when test="count(localedata/title)">
				<portal:title>
					<xsl:for-each select="localedata[@locale and title]">
						<!-- base:nls-string -->
						<base:nls-string>
							<!-- @lang -->
							<xsl:attribute name="lang">
								<xsl:value-of select="translate(@locale, '_', '-')" />
							</xsl:attribute>
							<xsl:value-of select="title" />
						</base:nls-string>
					</xsl:for-each>
				</portal:title>
			</xsl:when>
			<xsl:otherwise>
				<portal:title>
					<base:nls-string />
				</portal:title>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- portal:description -->
	<xsl:template name="description">
		<!-- portal:description -->
		<xsl:if test="count(localedata/description)">
			<portal:description>
				<xsl:for-each select="localedata[@locale and description]">
					<!-- base:nls-string -->
					<base:nls-string>
						<!-- @lang -->
						<xsl:attribute name="lang">
							<xsl:value-of select="translate(@locale, '_', '-')" />
						</xsl:attribute>
						<xsl:value-of select="description" />
					</base:nls-string>
				</xsl:for-each>
			</portal:description>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='language'] -->
	<xsl:template name="language">
		<xsl:if test="count(parameter[contains(@name, 'language.')])">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>language</xsl:text>
				</base:name>
				<xsl:for-each select="parameter[contains(@name, 'language.')]">
					<!-- base:value -->
					<base:value>
						<xsl:value-of select="." />
					</base:value>
				</xsl:for-each>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='default-language'] -->
	<xsl:template name="default-language">
		<xsl:variable name="language" select="parameter[@name='locale.default.language']" />
		<xsl:if test="$language and string-length($language)&gt;0">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>default-language</xsl:text>
				</base:name>
				<base:value>
					<xsl:variable name="country" select="parameter[@name='locale.default.country']" />
					<xsl:choose>
						<xsl:when test="$country and string-length($country)&gt;0">
							<xsl:variable name="variant" select="parameter[@name='locale.default.variant']" />
							<xsl:choose>
								<xsl:when test="$variant and string-length($variant)&gt;0">
									<xsl:value-of select="concat($language, '_', $country, '_', $variant)" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="concat($language, '_', $country)" />
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$language" />
						</xsl:otherwise>
					</xsl:choose>
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='uniquename'] -->
	<xsl:template name="uniquename">
		<xsl:if test="@uniquename">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>uniquename</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@uniquename" />
				</base:value>
			</portal:parameter>
		</xsl:if>
		<xsl:if test="not(@uniquename) and (name()='theme' or name()='skin')">
			<portal:parameter>
				<base:name>
					<xsl:text>uniquename</xsl:text>
				</base:name>
				<base:value>
					<xsl:text>wps.</xsl:text>
					<xsl:value-of select="name()"/>
					<xsl:text>.</xsl:text>
					<xsl:value-of select="@resourceroot"/>
					<xsl:text>.</xsl:text>
					<xsl:value-of select="@objectid"/>
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='objectid'] -->
	<xsl:template name="objectid">
		<xsl:if test="@objectid">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>objectid</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@objectid" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='web-app-uid'] -->
	<xsl:template name="web-app-uid">
		<xsl:param name="web-app-uid" />
		<xsl:if test="$web-app-uid">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>web-app-uid</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="$web-app-uid" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='portlet-app-uid'] -->
	<xsl:template name="portlet-app-uid">
		<xsl:param name="portlet-app-uid" />
		<xsl:if test="$portlet-app-uid">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>portlet-app-uid</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="$portlet-app-uid" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='portlet-name'] -->
	<xsl:template name="portlet-name">
		<xsl:if test="@name">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>portlet-name</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@name" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='active'] -->
	<xsl:template name="active">
		<xsl:if test="@active">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>active</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@active" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='ordinal'] -->
	<xsl:template name="ordinal">
		<xsl:if test="@ordinal">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>ordinal</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@ordinal" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='width'] -->
	<xsl:template name="width">
		<xsl:if test="@width">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>width</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@width" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='default'] -->
	<xsl:template name="default">
		<xsl:if test="@default">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>default</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@default" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='resourceroot'] -->
	<xsl:template name="resourceroot">
		<xsl:if test="@resourceroot">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>resourceroot</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@resourceroot" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='IgnoreAccessControlInCache'] -->
	<xsl:template name="IgnoreAccessControlInCaches">
		<xsl:if test="parameter[@name='IgnoreAccessControlInCaches']">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>IgnoreAccessControlInCaches</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="parameter[@name='IgnoreAccessControlInCaches']" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='remote-cache-expiry'] -->
	<xsl:template name="remote-cache-expiry">
		<xsl:if test="parameter[@name='remote-cache-expiry']">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>remote-cache-expiry</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="parameter[@name='remote-cache-expiry']" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='remote-cache-scope'] -->
	<xsl:template name="remote-cache-scope">
		<xsl:if test="parameter[@name='remote-cache-scope']">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>remote-cache-scope</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="parameter[@name='remote-cache-scope']" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>
	
<!-- wiring -->
	<xsl:template name="immediate-switch">
		<xsl:if test="@immediate-switch">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>immediate-switch</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@immediate-switch" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<xsl:template name="source-portletinstanceref">
		<xsl:variable name="instanceref">
			<xsl:value-of select="@source-portletinstanceref"/>
		</xsl:variable>	
	
		<xsl:if test="$instanceref">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>source-portletinstanceref</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="concat(local-name( ..//portletinstance[@objectid = $instanceref]/.. ), '.', generate-id( ..//portletinstance[@objectid = $instanceref]/.. ), '.', $unique-identifier)" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<xsl:template name="source-action">
		<xsl:if test="@source-action">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>source-action</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@source-action" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="source-param">
		<xsl:if test="@source-param">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>source-param</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@source-param" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>	
	
	<xsl:template name="source-property">
		<xsl:if test="@source-property">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>source-property</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@source-property" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<xsl:template name="target-action">
		<xsl:if test="@target-action">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>target-action</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@target-action" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="target-param">
		<xsl:if test="@target-param">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>target-param</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@target-param" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="target-property">
		<xsl:if test="@target-property">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>target-property</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@target-property" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>	
	
	<xsl:template name="target-portletinstanceref">
		<xsl:variable name="instanceref">
			<xsl:value-of select="@target-portletinstanceref"/>
		</xsl:variable>
	
		<xsl:if test="$instanceref">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>target-portletinstanceref</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="concat(local-name( ..//portletinstance[@objectid = $instanceref]/.. ), '.', generate-id( ..//portletinstance[@objectid = $instanceref]/.. ), '.', $unique-identifier)" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="user">
		<xsl:if test="@user">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>user</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@user" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="wireref">
		<xsl:if test="wire and wire[@user = 'anonymous portal user']">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>wireref</xsl:text>
				</base:name>
				<!-- base:value -->
				<xsl:for-each select="wire[@user = 'anonymous portal user']" >
					<base:value>
						<xsl:value-of select="concat(local-name(), '.', generate-id(), '.', $unique-identifier)" />
					</base:value>
				</xsl:for-each>
			</portal:parameter>
		</xsl:if>	
	</xsl:template>

	<!-- portal:parameter[portal:name='supported-markup'] -->
	<xsl:template name="supported-markup">
		<xsl:if test="count(supported-markup[@markup])">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>supported-markup</xsl:text>
				</base:name>
				<xsl:for-each select="supported-markup[@markup]">
					<!-- base:value -->
					<base:value>
						<xsl:value-of select="@markup" />
					</base:value>
				</xsl:for-each>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='url'] portal:parameter[portal:name='label'] portal:parameter[portal:name='url-mapping-objectid']-->
	<xsl:template name="url-internal">
		<xsl:call-template name="url-internal-url" />
		<xsl:call-template name="url-internal-label" />
		<xsl:call-template name="url-internal-url-mapping-objectid" />
	</xsl:template>

	<xsl:template name="url-internal-url">
		<xsl:if test="count(supported-markup[@markup])">
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>url</xsl:text>
				</base:name>
				<!-- base:value -->
				<xsl:for-each select="supported-markup[@markup]">
					<base:value>
						<xsl:variable name="url" select="." />
						<xsl:choose>
							<xsl:when test="starts-with($url, '/wps/myportal/')">
								<xsl:variable name="label" select="substring-after($url, '/wps/myportal/')" />
								<xsl:choose>
									<xsl:when test="/request/portal/url-mapping-context[@label=$label]">
										<xsl:variable name="resourceref" select="/request/portal/url-mapping-context[@label=$label]/portal-url/@resourceref" />
										<xsl:apply-templates select="/request/portal/content-node[starts-with(@objectid, $resourceref)]" mode="url-internal" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="$url" />
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$url" />
							</xsl:otherwise>
						</xsl:choose>
					</base:value>
				</xsl:for-each>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<xsl:template match="/request/portal/content-node" mode="url-internal">
		<xsl:value-of select="concat('navigation-element', '.', generate-id(), '.', $unique-identifier)" />
	</xsl:template>
	
	<xsl:template name="url-internal-label">
		<xsl:variable name="url" select="supported-markup[1]" />
		<xsl:if test="starts-with($url, '/wps/myportal/')">
			<xsl:variable name="label" select="substring-after($url, '/wps/myportal/')" />
			<xsl:if test="/request/portal/url-mapping-context[@label=$label]">
				<portal:parameter>
					<!-- base:name -->
					<base:name>
						<xsl:text>label</xsl:text>
					</base:name>
					<!-- base:value -->
					<base:value>
						<xsl:value-of select="$label" />
					</base:value>
				</portal:parameter>
			</xsl:if>
		</xsl:if>
	</xsl:template>

	<xsl:template name="url-internal-url-mapping-objectid">
		<xsl:variable name="url" select="supported-markup[1]" />
		<xsl:if test="starts-with($url, '/wps/myportal/')">
			<xsl:variable name="label" select="substring-after($url, '/wps/myportal/')" />
			<xsl:if test="/request/portal/url-mapping-context[@label=$label]">
				<xsl:variable name="url-mapping-objectid" select="/request/portal/url-mapping-context[@label=$label]/@objectid" />
				<portal:parameter>
					<!-- base:name -->
					<base:name>
						<xsl:text>url-mapping-objectid</xsl:text>
					</base:name>
					<!-- base:value -->
					<base:value>
						<xsl:value-of select="$url-mapping-objectid" />
					</base:value>
				</portal:parameter>
			</xsl:if>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='url'] -->
	<xsl:template name="url-external">
		<xsl:if test="count(supported-markup[@markup])">
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>url</xsl:text>
				</base:name>
				<!-- base:value -->
				<xsl:for-each select="supported-markup[@markup]">
					<base:value>
						<xsl:value-of select="." />
					</base:value>
				</xsl:for-each>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='type'] -->
	<xsl:template name="type-internal">
		<!-- portal:parameter -->
		<portal:parameter>
			<!-- base:name -->
			<base:name>
				<xsl:text>type</xsl:text>
			</base:name>
			<!-- base:value -->
			<base:value>
				<xsl:text>internal</xsl:text>
			</base:value>
		</portal:parameter>
	</xsl:template>

	<!-- portal:parameter[portal:name='type'] -->
	<xsl:template name="type-external">
		<!-- portal:parameter -->
		<portal:parameter>
			<!-- base:name -->
			<base:name>
				<xsl:text>type</xsl:text>
			</base:name>
			<!-- base:value -->
			<base:value>
				<xsl:text>external</xsl:text>
			</base:value>
		</portal:parameter>
	</xsl:template>

	<!-- portal:parameter[portal:name='defaultskinref'] -->
	<xsl:template name="defaultskinref">
		<xsl:if test="@defaultskinref">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>defaultskinref</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:choose>
						<xsl:when test="@defaultskinref='undefined'">
							<xsl:value-of select="@defaultskinref" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:variable name="defaultskinref" select="@defaultskinref" />
							<xsl:apply-templates select="/request/portal/skin[starts-with(@objectid, $defaultskinref)]" mode="defaultskinref" />
						</xsl:otherwise>
					</xsl:choose>
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<xsl:template match="/request/portal/skin" mode="defaultskinref">
		<xsl:value-of select="concat(local-name(), '.', generate-id(), '.', $unique-identifier)" />
	</xsl:template>
	
	<!-- portal:parameter[portal:name='skinref'] -->
	<xsl:template name="skinref">
		<xsl:if test="@skinref">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>skinref</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:choose>
						<xsl:when test="@skinref='undefined'">
							<xsl:value-of select="@skinref" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:variable name="skinref" select="@skinref" />
							<xsl:apply-templates select="/request/portal/skin[starts-with(@objectid, $skinref)]" mode="skinref" />
						</xsl:otherwise>
					</xsl:choose>
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<xsl:template match="/request/portal/skin" mode="skinref">
		<xsl:value-of select="concat(local-name(), '.', generate-id(), '.', $unique-identifier)" />
	</xsl:template>
	
	<!-- portal:parameter[portal:name='themeref'] -->
	<xsl:template name="themref">
		<xsl:if test="@themeref">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>themeref</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:choose>
						<xsl:when test="@themeref='undefined'">
							<xsl:value-of select="@themeref" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:variable name="themeref" select="@themeref" />
							<xsl:apply-templates select="/request/portal/theme[starts-with(@objectid, $themeref)]" mode="themeref" />
						</xsl:otherwise>
					</xsl:choose>
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<xsl:template match="/request/portal/theme" mode="themeref">
		<xsl:value-of select="concat(local-name(), '.', generate-id(), '.', $unique-identifier)" />
	</xsl:template>
	
	<!-- portal:parameter[portal:name='allowed-skin'] -->
	<xsl:template name="allowed-skin">
		<xsl:if test="count(allowed-skin[@skin])">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>allowed-skin</xsl:text>
				</base:name>
				<xsl:for-each select="allowed-skin[@skin]">
					<!-- base:value -->
					<base:value>
						<xsl:choose>
							<xsl:when test="@skin='undefined'">
								<xsl:value-of select="@skin" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:variable name="skin" select="@skin" />
								<xsl:apply-templates select="/request/portal/skin[starts-with(@objectid, $skin)]" mode="allowed-skin" />
							</xsl:otherwise>
						</xsl:choose>
					</base:value>
				</xsl:for-each>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<xsl:template match="/request/portal/skin" mode="allowed-skin">
		<xsl:value-of select="concat(local-name(), '.', generate-id(), '.', $unique-identifier)" />
	</xsl:template>
	
	<!-- portal:parameter[portal:name='allportletsallowed'] -->
	<xsl:template name="allportletsallowed">
		<xsl:if test="@allportletsallowed">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>allportletsallowed</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@allportletsallowed" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='shareable'] -->
	<xsl:template name="shareable">
		<xsl:if test="@shareable">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>shareable</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@shareable" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='derivation-parentref'] -->
	<xsl:template name="derivation-parentref">
		<xsl:if test="@derivation-parentref">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>derivation-parentref</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:choose>
						<xsl:when test="@derivation-parentref='undefined'">
							<xsl:value-of select="@derivation-parentref" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:variable name="derivation-parentref" select="@derivation-parentref" />
							<xsl:apply-templates select="/request/portal/content-node[starts-with(@objectid, $derivation-parentref)]" mode="derivation-parentref" />
						</xsl:otherwise>
					</xsl:choose>
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<xsl:template match="/request/portal/content-node" mode="derivation-parentref">
		<xsl:value-of select="concat(local-name(), '.', generate-id(), '.', $unique-identifier)" />
	</xsl:template>
	
	<!-- portal:parameter[portal:name='allowed-portlet'] -->
	<xsl:template name="allowed-portlet">
		<xsl:if test="count(allowed-portlet[@portlet])">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>allowed-portlet</xsl:text>
				</base:name>
				<xsl:for-each select="allowed-portlet[@portlet]">
					<!-- base:value -->
					<base:value>
						<xsl:choose>
							<xsl:when test="@portlet='undefined'">
								<xsl:value-of select="@portlet" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:variable name="portlet" select="@portlet" />
								<xsl:apply-templates select="/request/portal/web-app/portlet-app/portlet[starts-with(@objectid, $portlet)]" mode="allowed-portlet" />
							</xsl:otherwise>
						</xsl:choose>
					</base:value>
				</xsl:for-each>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:application-element-ref -->
	<xsl:template match="/request/portal/web-app/portlet-app/portlet" mode="allowed-portlet">
		<xsl:value-of select="concat(local-name(), '.', generate-id(), '.', $unique-identifier)" />
	</xsl:template>
	
	<!-- portal:parameter[portal:name='bookmarkable'] -->
	<xsl:template name="bookmarkable">
		<xsl:if test="count(parameter[@name='bookmarkable'])">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>bookmarkable</xsl:text>
				</base:name>
				<xsl:for-each select="parameter[@name='bookmarkable']">
					<!-- base:value -->
					<base:value>
						<xsl:choose>
							<xsl:when test=".='Yes'">
								<xsl:value-of select="'true'" />
							</xsl:when>
							<xsl:when test=".='No'">
								<xsl:value-of select="'false'" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="'false'" />
							</xsl:otherwise>
						</xsl:choose>
					</base:value>
				</xsl:for-each>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='deletable'] -->
	<xsl:template name="deletable">
		<xsl:if test="@deletable">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>deletable</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@deletable" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='modifiable'] -->
	<xsl:template name="modifiable">
		<xsl:if test="@modifiable">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>modifiable</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@modifiable" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='movable'] -->
	<xsl:template name="movable">
		<xsl:if test="@movable">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>movable</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@movable" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='nestable'] -->
	<xsl:template name="nestable">
		<xsl:if test="@nestable">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>nestable</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:value-of select="@nestable" />
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<!-- portal:parameter[portal:name='shadowref'] -->
	<xsl:template name="shadowref">
		<xsl:if test="@shadowref">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>shadowref</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:choose>
						<xsl:when test="@shadowref='undefined'">
							<xsl:value-of select="@shadowref" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:variable name="shadowref" select="@shadowref" />
							<xsl:apply-templates select="//component[starts-with(@objectid, $shadowref)]" mode="shadowref" />
						</xsl:otherwise>
					</xsl:choose>
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<xsl:template match="component" mode="shadowref">
		<xsl:value-of select="concat(local-name(), '.', generate-id(), '.', $unique-identifier)" />
	</xsl:template>
	
	<!-- portal:parameter[portal:name='shadow-parentref'] -->
	<xsl:template name="shadow-parentref">
		<xsl:if test="@shadow-parentref">
			<!-- portal:parameter -->
			<portal:parameter>
				<!-- base:name -->
				<base:name>
					<xsl:text>shadow-parentref</xsl:text>
				</base:name>
				<!-- base:value -->
				<base:value>
					<xsl:choose>
						<xsl:when test="@shadow-parentref='undefined'">
							<xsl:value-of select="@shadow-parentref" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:variable name="shadow-parentref" select="@shadow-parentref" />
							<xsl:apply-templates select="//component[starts-with(@objectid, $shadow-parentref)]" mode="shadow-parentref" />
						</xsl:otherwise>
					</xsl:choose>
				</base:value>
			</portal:parameter>
		</xsl:if>
	</xsl:template>

	<xsl:template match="component" mode="shadow-parentref">
		<xsl:value-of select="concat(local-name(), '.', generate-id(), '.', $unique-identifier)" />
	</xsl:template>
	
	<!-- @application-element-ref -->
	<xsl:template name="application-element-ref">
		<xsl:attribute name="application-element-ref">
			<xsl:value-of select="concat(local-name(), '.', generate-id(), '.', $unique-identifier)" />
		</xsl:attribute>
	</xsl:template>

	<!-- @layout-element-ref -->
	<xsl:template name="layout-element-ref">
		<xsl:attribute name="layout-element-ref">
			<xsl:value-of select="concat(local-name(), '.', generate-id(), '.', $unique-identifier)" />
		</xsl:attribute>
	</xsl:template>

	<!-- portal:application-element-ref -->
	<xsl:template match="/request/portal/web-app/portlet-app/portlet" mode="application-element-ref">
		<xsl:value-of select="concat(local-name(), '.', generate-id(), '.', $unique-identifier)" />
	</xsl:template>
	
	<!-- Identity transformation template -->
	<xsl:template match="*|@*|comment()|processing-instruction()|text()">
		<xsl:copy>
			<xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()" />
		</xsl:copy>
	</xsl:template>
</xsl:stylesheet>
