/*
 * NodeTypeManager.java
 *
 * This file is part of the specification for the
 * Java Content Repository API
 */
package javax.jcr.nodetype;

import javax.jcr.*;

/**
 * Allows for the retrieval of node types.
 * Accessed via {@link Workspace#getNodeTypeManager}.
 *
 * @author Peeter Piegaze
 * @author Stefan Guggisberg
 */
public interface NodeTypeManager {

    /**
     * Returns an iterator over all available node types.
     *
     * @return An <code>NodeTypeIterator</code>.
     *
     * @throws RepositoryException if an error occurs.
     */
    public NodeTypeIterator getAllNodeTypes() throws RepositoryException;

    /**
     * Returns the named node type. Throws a
     * <code>NoSuchNodeTypeException</code> if a node type by that name
     * does not exist.
     *
     * @param nodeTypeName the name of an existing node type.
     *
     * @return A <code>NodeType</code> object.
     *
     * @throws NoSuchNodeTypeException if no node type by the given name exists.
     */
    public NodeType getNodeType(String nodeTypeName) throws NoSuchNodeTypeException;
}