/*
 * EventType.java
 *
 * This file is part of the specification for the
 * Java Content Repository API
 */
package javax.jcr.observation;

/**
 * The event types used by the <code>ObservationManager</code>.
 * <p>
 * <p>This interface defines the following event types:
 * <UL>
 *    <LI>ITEM_ADDED
 *    <LI>ITEM_CHANGED
 *    <LI>ITEM_REMOVED
 *    <LI>ITEM_VERSIONED
 *    <LI>LABEL_ADDED
 *    <LI>LABEL_REMOVED
 *    <LI>ITEM_LOCKED
 *    <LI>ITEM_UNLOCKED
 *    <LI>LOCK_EXPIRED
 * </UL>
 * <b>Level 2 only</b></code>
 * <p>
 * @author Peeter Piegaze
 * @author Stefan Guggisberg
 */
public interface EventType {

    /**
     * The event types defined by the JCR standard. Each constant is a
     * power of 2 (i.e. sets of event types can be encoded as a bitmask
     * in a <code>long</code> value).
     */
    public static final long ITEM_ADDED = 1;
    public static final long ITEM_CHANGED = 2;
    public static final long ITEM_REMOVED = 4;
    public static final long ITEM_VERSIONED = 8;
    public static final long LABEL_ADDED = 16;
    public static final long LABEL_REMOVED = 32;
    public static final long ITEM_LOCKED = 64;
    public static final long ITEM_UNLOCKED = 128;
    public static final long LOCK_EXPIRED = 256;

    /**
     * Returns the numerical constant identifying this event type. This value
     * is always a power of 2 ((i.e. sets of event types can be encoded as
     * a bitmask in a <code>long</code> value).
     * @return the numerical value
     * @see ObservationManager
     */
    public long getValue();

    /**
     * Returns the descriptive name of this event type.
     * @return the name
     * @see ObservationManager
     */
    public String getName();
}