/*
 * VersionControlEvent.java
 *
 * This file is part of the specification for the
 * Java Content Repository API
 */
package javax.jcr.observation;

import javax.jcr.NodeIterator;

/**
 * A subclass of <code>Event</code> representing a "version control" event.
 * <p>
 * <b>Level 2 only</b>
 * <p>
 * Will always be one of:
 * <ul>
 * <li><code>EventType.ITEM_VERSIONED</code>.
 * <li><code>EventType.LABEL_ADDED</code>.
 * <li><code>EventType.LABEL_REMOVED</code>.
 * </ul>
 * For details see the <i>ObservationManager</i> section of the JCR standard document.
 *
 * @author tima, ppiegaze
 */
public interface VersionControlEvent extends Event {

    /**
     * Returns the version name assigned by the <code>Node.createVersion</code>
     * that triggered this event.
     *
     * @return The version name assigned by the <code>Node.createVersion</code>
     * that triggered this event.
     */
    public String getVersionName();

    /**
     * Returns the version label (if any) assigned by the
     * <code>Node.createVersion</code> that triggered this event.
     *
     * @return The version label (if any) assigned by the
     * <code>Node.createVersion</code> that triggered this event.
     */
    public String getVersionLabel();

    /**
     * Returns the comment (if any) assigned by the
     * <code>Node.createVersion</code> that triggered this event.
     *
     * @return The comment (if any) assigned by the
     * <code>Node.createVersion</code> that triggered this event.
     */
    public String getVersionComment();

    /**
     * Returns the predecessor(s) of the node just versioned.
     *
     * @return the predecessors of the node just versioned.
     */
    public NodeIterator getPredecessors();
}
